==> openflowplugin-extension-nicira-0.7.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/get/flow/statistics/output/flow/and/statistics/map/list/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.get.flow.statistics.output.flow.and.statistics.map.list.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.multipath.grouping.NxMultipath;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder} instances.
 *
 * @see NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder
 *
 */
public class NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder implements Builder<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase> {

    private NxMultipath _nxMultipath;


    Map<Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> augmentation = Collections.emptyMap();

    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder() {
    }
    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionMultipathGrouping arg) {
        this._nxMultipath = arg.getNxMultipath();
    }

    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder(NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase base) {
        this._nxMultipath = base.getNxMultipath();
        if (base instanceof NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl) {
            NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl impl = (NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> aug =((AugmentationHolder<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionMultipathGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionMultipathGrouping) {
            this._nxMultipath = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionMultipathGrouping)arg).getNxMultipath();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionMultipathGrouping]");
    }

    public NxMultipath getNxMultipath() {
        return _nxMultipath;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder setNxMultipath(final NxMultipath value) {
        this._nxMultipath = value;
        return this;
    }
    
    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> augmentationType, Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase build() {
        return new NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl(this);
    }

    private static final class NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl implements NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase {
    
        private final NxMultipath _nxMultipath;
    
        private Map<Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> augmentation = Collections.emptyMap();
    
        NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl(NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder base) {
            this._nxMultipath = base.getNxMultipath();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase> getImplementedInterface() {
            return NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase.class;
        }
    
        @Override
        public NxMultipath getNxMultipath() {
            return _nxMultipath;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxMultipath);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase other = (NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase)obj;
            if (!Objects.equals(_nxMultipath, other.getNxMultipath())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl otherImpl = (NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase");
            CodeHelpers.appendValue(helper, "_nxMultipath", _nxMultipath);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.7.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/get/flow/statistics/output/flow/and/statistics/map/list/instructions/instruction/instruction/write/actions/_case/write/actions/action/action/NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.get.flow.statistics.output.flow.and.statistics.map.list.instructions.instruction.instruction.write.actions._case.write.actions.action.action;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.nx.action.multipath.grouping.NxMultipath;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder} instances.
 *
 * @see NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder
 *
 */
public class NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder implements Builder<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase> {

    private NxMultipath _nxMultipath;


    Map<Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> augmentation = Collections.emptyMap();

    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder() {
    }
    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionMultipathGrouping arg) {
        this._nxMultipath = arg.getNxMultipath();
    }

    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder(NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase base) {
        this._nxMultipath = base.getNxMultipath();
        if (base instanceof NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl) {
            NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl impl = (NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> aug =((AugmentationHolder<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionMultipathGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionMultipathGrouping) {
            this._nxMultipath = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionMultipathGrouping)arg).getNxMultipath();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionMultipathGrouping]");
    }

    public NxMultipath getNxMultipath() {
        return _nxMultipath;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder setNxMultipath(final NxMultipath value) {
        this._nxMultipath = value;
        return this;
    }
    
    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder addAugmentation(Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> augmentationType, Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder removeAugmentation(Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase build() {
        return new NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl(this);
    }

    private static final class NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl implements NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase {
    
        private final NxMultipath _nxMultipath;
    
        private Map<Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> augmentation = Collections.emptyMap();
    
        NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl(NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseBuilder base) {
            this._nxMultipath = base.getNxMultipath();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase> getImplementedInterface() {
            return NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase.class;
        }
    
        @Override
        public NxMultipath getNxMultipath() {
            return _nxMultipath;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_nxMultipath);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase other = (NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase)obj;
            if (!Objects.equals(_nxMultipath, other.getNxMultipath())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl otherImpl = (NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>>, Augmentation<NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("NxActionMultipathNotifDirectStatisticsUpdateWriteActionsCase");
            CodeHelpers.appendValue(helper, "_nxMultipath", _nxMultipath);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
